@@ -117,13 +117,14 @@ xfconf_property_is_valid(const gchar *property,
     while(*p) {
         if(!(*p >= 'A' && *p <= 'Z') && !(*p >= 'a' && *p <= 'z')
            && !(*p >= '0' && *p <= '9')
-           && *p != '_' && *p != '-' && *p != '/'
-           && !(*p == '<' || *p == '>'))
+           && *p != '_' && *p != '-' && *p != '/' && *p != '{' && *p != '}'
+           && !(*p == '<' || *p == '>') && *p != '|' && *p != ','
+           && *p != '[' && *p != ']' && *p != '.' && *p != ':')
         {
             if(error) {
                 g_set_error(error, XFCONF_ERROR,
                             XFCONF_ERROR_INVALID_PROPERTY,
-                            _("Property names can only include the ASCII characters A-Z, a-z, 0-9, '_', '-', '<' and '>', as well as '/' as a separator"));
+                            _("Property names can only include the ASCII characters A-Z, a-z, 0-9, '_', '-', ':', '.', ',', '[', ']', '{', '}', '<' and '>', as well as '/' as a separator"));
             }
             return FALSE;
         }
@@ -168,12 +169,14 @@ xfconf_channel_is_valid(const gchar *channel,
     while(*p) {
         if(!(*p >= 'A' && *p <= 'Z') && !(*p >= 'a' && *p <= 'z')
            && !(*p >= '0' && *p <= '9')
-           && *p != '_' && *p != '-')
+           && *p != '_' && *p != '-' && *p != '{' && *p != '}'
+           && *p != '|' && *p != ','
+           && *p != '[' && *p != ']' && *p != '.' && *p != ':')
         {
             if(error) {
                 g_set_error(error, XFCONF_ERROR,
                             XFCONF_ERROR_INVALID_CHANNEL,
-                            _("Channel names can only include the ASCII characters A-Z, a-z, 0-9, '_', and '-'"));
+                            _("Channel names can only include the ASCII characters A-Z, a-z, 0-9, '{', '}', '|', ']', '[', ':', ',', '.', '_', and '-'"));
             }
             return FALSE;
         }
